@@ -1,30 +1,9 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "itemlibrarywidget.h"
 
+#include "itemlibraryconstants.h"
 #include "itemlibraryiconimageprovider.h"
 #include "itemlibraryimport.h"
 
@@ -35,21 +14,28 @@
 #include <designermcumanager.h>
 #include <documentmanager.h>
 #include <itemlibraryaddimportmodel.h>
+#include <itemlibraryentry.h>
 #include <itemlibraryimageprovider.h>
-#include <itemlibraryinfo.h>
+#ifndef QDS_USE_PROJECTSTORAGE
+#  include <itemlibraryinfo.h>
+#endif
 #include <itemlibrarymodel.h>
-#include <metainfo.h>
 #include <model.h>
+#include <model/modelutils.h>
 #include <rewritingexception.h>
 #include <qmldesignerconstants.h>
 #include <qmldesignerplugin.h>
+#ifndef QDS_USE_PROJECTSTORAGE
+#  include <metainfo.h>
+#endif
 
 #include <utils/algorithm.h>
-#include <utils/flowlayout.h>
-#include <utils/fileutils.h>
+#include <utils/environment.h>
 #include <utils/filesystemwatcher.h>
-#include <utils/stylehelper.h>
+#include <utils/fileutils.h>
+#include <utils/flowlayout.h>
 #include <utils/qtcassert.h>
+#include <utils/stylehelper.h>
 #include <utils/utilsicons.h>
 
 #include <coreplugin/coreconstants.h>
@@ -80,7 +66,7 @@ namespace QmlDesigner {
 static QString propertyEditorResourcesPath()
 {
 #ifdef SHARE_QML_PATH
-    if (qEnvironmentVariableIsSet("LOAD_QML_FROM_SOURCE"))
+    if (::Utils::qtcEnvironmentVariableIsSet("LOAD_QML_FROM_SOURCE"))
         return QLatin1String(SHARE_QML_PATH) + "/propertyEditorQmlSources";
 #endif
     return Core::ICore::resourcePath("qmldesigner/propertyEditorQmlSources").toString();
@@ -92,40 +78,34 @@ bool ItemLibraryWidget::eventFilter(QObject *obj, QEvent *event)
     Model *model = document ? document->documentModel() : nullptr;
 
     if (event->type() == QEvent::FocusOut) {
-        if (obj == m_itemsWidget.data())
+        if (obj == m_itemsWidget->quickWidget())
             QMetaObject::invokeMethod(m_itemsWidget->rootObject(), "closeContextMenu");
     } else if (event->type() == QMouseEvent::MouseMove) {
         if (m_itemToDrag.isValid()) {
             QMouseEvent *me = static_cast<QMouseEvent *>(event);
-            if ((me->globalPos() - m_dragStartPoint).manhattanLength() > 10) {
+            if ((me->globalPosition().toPoint() - m_dragStartPoint).manhattanLength() > 10) {
                 ItemLibraryEntry entry = m_itemToDrag.value<ItemLibraryEntry>();
                 // For drag to be handled correctly, we must have the component properly imported
                 // beforehand, so we import the module immediately when the drag starts
-                if (!entry.requiredImport().isEmpty()) {
-                    // We don't know if required import is library of file import, so try both.
-                    Import libImport = Import::createLibraryImport(entry.requiredImport());
-                    Import fileImport = Import::createFileImport(entry.requiredImport());
-                    if (!m_model->hasImport(libImport, true, true)
-                            && !m_model->hasImport(fileImport, true, true)) {
-                        const QList<Import> possImports = m_model->possibleImports();
-                        for (const auto &possImport : possImports) {
-                            if ((!possImport.url().isEmpty() && possImport.url() == libImport.url())
-                                || (!possImport.file().isEmpty() && possImport.file() == fileImport.file())) {
-                                m_model->changeImports({possImport}, {});
-                                break;
-                            }
-                        }
-                    }
+                if (!entry.requiredImport().isEmpty()
+                    && !ModelUtils::addImportWithCheck(entry.requiredImport(), m_model)) {
+                    qWarning() << __FUNCTION__ << "Required import adding failed:"
+                               << entry.requiredImport();
                 }
 
                 if (model) {
                     model->startDrag(m_itemLibraryModel->getMimeData(entry),
-                                     Utils::StyleHelper::dpiSpecificImageFile(entry.libraryEntryIconPath()));
+                                     ::Utils::StyleHelper::dpiSpecificImageFile(
+                                         entry.libraryEntryIconPath()));
                 }
 
                 m_itemToDrag = {};
             }
         }
+    } else if (event->type() == QMouseEvent::MouseButtonRelease) {
+        m_itemToDrag = {};
+
+        setIsDragging(false);
     }
 
     return QObject::eventFilter(obj, event);
@@ -138,9 +118,9 @@ void ItemLibraryWidget::resizeEvent(QResizeEvent *event)
 
 ItemLibraryWidget::ItemLibraryWidget(AsynchronousImageCache &imageCache)
     : m_itemIconSize(24, 24)
-    , m_itemLibraryModel(new ItemLibraryModel(this))
-    , m_addModuleModel(new ItemLibraryAddImportModel(this))
-    , m_itemsWidget(new QQuickWidget(this))
+    , m_itemLibraryModel(std::make_unique<ItemLibraryModel>())
+    , m_addModuleModel(std::make_unique<ItemLibraryAddImportModel>())
+    , m_itemsWidget(Utils::makeUniqueObjectPtr<StudioQuickWidget>())
     , m_imageCache{imageCache}
 {
     m_compressionTimer.setInterval(1000);
@@ -151,37 +131,27 @@ ItemLibraryWidget::ItemLibraryWidget(AsynchronousImageCache &imageCache)
     setMinimumWidth(100);
 
     // set up Component Library view and model
+    m_itemsWidget->quickWidget()->setObjectName(Constants::OBJECT_NAME_COMPONENT_LIBRARY);
     m_itemsWidget->setResizeMode(QQuickWidget::SizeRootObjectToView);
     m_itemsWidget->engine()->addImportPath(propertyEditorResourcesPath() + "/imports");
 
-    m_itemsWidget->rootContext()->setContextProperties({
-        {"itemLibraryModel", QVariant::fromValue(m_itemLibraryModel.data())},
-        {"addModuleModel", QVariant::fromValue(m_addModuleModel.data())},
-        {"itemLibraryIconWidth", m_itemIconSize.width()},
-        {"itemLibraryIconHeight", m_itemIconSize.height()},
-        {"rootView", QVariant::fromValue(this)},
-        {"widthLimit", HORIZONTAL_LAYOUT_WIDTH_LIMIT},
-        {"highlightColor", Utils::StyleHelper::notTooBrightHighlightColor()},
-    });
-
     m_previewTooltipBackend = std::make_unique<PreviewTooltipBackend>(m_imageCache);
-    m_itemsWidget->rootContext()->setContextProperty("tooltipBackend", m_previewTooltipBackend.get());
 
     m_itemsWidget->setClearColor(Theme::getColor(Theme::Color::DSpanelBackground));
     m_itemsWidget->engine()->addImageProvider(QStringLiteral("qmldesigner_itemlibrary"),
                                                       new Internal::ItemLibraryImageProvider);
     Theme::setupTheme(m_itemsWidget->engine());
-    m_itemsWidget->installEventFilter(this);
+    m_itemsWidget->quickWidget()->installEventFilter(this);
 
     auto layout = new QVBoxLayout(this);
     layout->setContentsMargins({});
     layout->setSpacing(0);
-    layout->addWidget(m_itemsWidget.data());
+    layout->addWidget(m_itemsWidget.get());
 
     updateSearch();
 
     setStyleSheet(Theme::replaceCssColors(
-        QString::fromUtf8(Utils::FileReader::fetchQrc(":/qmldesigner/stylesheet.css"))));
+        QString::fromUtf8(::Utils::FileReader::fetchQrc(":/qmldesigner/stylesheet.css"))));
 
     m_qmlSourceUpdateShortcut = new QShortcut(QKeySequence(Qt::CTRL + Qt::Key_F5), this);
     connect(m_qmlSourceUpdateShortcut, &QShortcut::activated, this, &ItemLibraryWidget::reloadQmlSource);
@@ -194,11 +164,24 @@ ItemLibraryWidget::ItemLibraryWidget(AsynchronousImageCache &imageCache)
     QmlDesignerPlugin::trackWidgetFocusTime(this, Constants::EVENT_ITEMLIBRARY_TIME);
 
     // init the first load of the QML UI elements
+
+    auto map = m_itemsWidget->registerPropertyMap("ItemLibraryBackend");
+
+    map->setProperties({{"itemLibraryModel", QVariant::fromValue(m_itemLibraryModel.get())},
+                        {"addModuleModel", QVariant::fromValue(m_addModuleModel.get())},
+                        {"itemLibraryIconWidth", m_itemIconSize.width()},
+                        {"itemLibraryIconHeight", m_itemIconSize.height()},
+                        {"rootView", QVariant::fromValue(this)},
+                        {"widthLimit", HORIZONTAL_LAYOUT_WIDTH_LIMIT},
+                        {"highlightColor", ::Utils::StyleHelper::notTooBrightHighlightColor()},
+                        {"tooltipBackend", QVariant::fromValue(m_previewTooltipBackend.get())}});
+
     reloadQmlSource();
 }
 
 ItemLibraryWidget::~ItemLibraryWidget() = default;
 
+#ifndef QDS_USE_PROJECTSTORAGE
 void ItemLibraryWidget::setItemLibraryInfo(ItemLibraryInfo *itemLibraryInfo)
 {
     if (m_itemLibraryInfo.data() == itemLibraryInfo)
@@ -207,19 +190,15 @@ void ItemLibraryWidget::setItemLibraryInfo(ItemLibraryInfo *itemLibraryInfo)
     if (m_itemLibraryInfo) {
         disconnect(m_itemLibraryInfo.data(), &ItemLibraryInfo::entriesChanged,
                    this, &ItemLibraryWidget::delayedUpdateModel);
-        disconnect(m_itemLibraryInfo.data(), &ItemLibraryInfo::priorityImportsChanged,
-                   this, &ItemLibraryWidget::handlePriorityImportsChanged);
     }
     m_itemLibraryInfo = itemLibraryInfo;
     if (itemLibraryInfo) {
         connect(m_itemLibraryInfo.data(), &ItemLibraryInfo::entriesChanged,
                 this, &ItemLibraryWidget::delayedUpdateModel);
-        connect(m_itemLibraryInfo.data(), &ItemLibraryInfo::priorityImportsChanged,
-                this, &ItemLibraryWidget::handlePriorityImportsChanged);
-        m_addModuleModel->setPriorityImports(m_itemLibraryInfo->priorityImports());
     }
     delayedUpdateModel();
 }
+#endif
 
 QList<QToolButton *> ItemLibraryWidget::createToolBarWidgets()
 {
@@ -227,7 +206,7 @@ QList<QToolButton *> ItemLibraryWidget::createToolBarWidgets()
 }
 
 
-void ItemLibraryWidget::handleSearchfilterChanged(const QString &filterText)
+void ItemLibraryWidget::handleSearchFilterChanged(const QString &filterText)
 {
     if (filterText != m_filterText) {
         m_filterText = filterText;
@@ -241,7 +220,7 @@ QString ItemLibraryWidget::getDependencyImport(const Import &import)
 
     const QStringList splitImport = import.url().split('.');
 
-    if (splitImport.count() > 1) {
+    if (splitImport.size() > 1) {
         if (prefixDependencies.contains(splitImport.first()))
             return splitImport.first();
     }
@@ -260,7 +239,7 @@ void ItemLibraryWidget::handleAddImport(int index)
                                                + importStr);
     }
 
-    QList<Import> imports;
+    Imports imports;
     const QString dependency = getDependencyImport(import);
 
     auto document = QmlDesignerPlugin::instance()->currentDesignDocument();
@@ -272,7 +251,11 @@ void ItemLibraryWidget::handleAddImport(int index)
             imports.append(dependencyImport);
     }
     imports.append(import);
-    model->changeImports(imports, {});
+    try {
+        model->changeImports(imports, {});
+    } catch (const Exception &e) {
+        e.showException();
+    }
 
     switchToComponentsView();
     updateSearch();
@@ -285,7 +268,7 @@ void ItemLibraryWidget::goIntoComponent(const QString &source)
 
 void ItemLibraryWidget::delayedUpdateModel()
 {
-    static bool disableTimer = DesignerSettings::getValue(DesignerSettingsKey::DISABLE_ITEM_LIBRARY_UPDATE_TIMER).toBool();
+    static bool disableTimer = QmlDesignerPlugin::settings().value(DesignerSettingsKey::DISABLE_ITEM_LIBRARY_UPDATE_TIMER).toBool();
     if (disableTimer)
         updateModel();
     else
@@ -295,10 +278,13 @@ void ItemLibraryWidget::delayedUpdateModel()
 void ItemLibraryWidget::setModel(Model *model)
 {
     m_model = model;
-    if (!model)
+    if (!model) {
+        m_itemToDrag = {};
         return;
-
+    }
+#ifndef QDS_USE_PROJECTSTORAGE
     setItemLibraryInfo(model->metaInfo().itemLibraryInfo());
+#endif
 
     if (DesignDocument *document = QmlDesignerPlugin::instance()->currentDesignDocument()) {
         const bool subCompEditMode = document->inFileComponentModelActive();
@@ -315,7 +301,7 @@ void ItemLibraryWidget::setModel(Model *model)
 QString ItemLibraryWidget::qmlSourcesPath()
 {
 #ifdef SHARE_QML_PATH
-    if (qEnvironmentVariableIsSet("LOAD_QML_FROM_SOURCE"))
+    if (::Utils::qtcEnvironmentVariableIsSet("LOAD_QML_FROM_SOURCE"))
         return QLatin1String(SHARE_QML_PATH) + "/itemLibraryQmlSources";
 #endif
     return Core::ICore::resourcePath("qmldesigner/itemLibraryQmlSources").toString();
@@ -335,7 +321,6 @@ void ItemLibraryWidget::reloadQmlSource()
 {
     const QString itemLibraryQmlPath = qmlSourcesPath() + "/ItemsView.qml";
     QTC_ASSERT(QFileInfo::exists(itemLibraryQmlPath), return);
-    m_itemsWidget->engine()->clearComponentCache();
     m_itemsWidget->setSource(QUrl::fromLocalFile(itemLibraryQmlPath));
 }
 
@@ -348,7 +333,7 @@ void ItemLibraryWidget::updateModel()
         m_compressionTimer.stop();
     }
 
-    m_itemLibraryModel->update(m_itemLibraryInfo.data(), m_model.data());
+    m_itemLibraryModel->update(m_model.data());
 
     if (m_itemLibraryModel->rowCount() == 0 && !m_updateRetry) {
         m_updateRetry = true; // Only retry once to avoid endless loops
@@ -359,13 +344,13 @@ void ItemLibraryWidget::updateModel()
     updateSearch();
 }
 
-void ItemLibraryWidget::updatePossibleImports(const QList<Import> &possibleImports)
+void ItemLibraryWidget::updatePossibleImports(const Imports &possibleImports)
 {
-    m_addModuleModel->update(possibleImports);
+    m_addModuleModel->update(set_difference(possibleImports, m_model->imports()));
     delayedUpdateModel();
 }
 
-void ItemLibraryWidget::updateUsedImports(const QList<Import> &usedImports)
+void ItemLibraryWidget::updateUsedImports(const Imports &usedImports)
 {
     m_itemLibraryModel->updateUsedImports(usedImports);
 }
@@ -377,11 +362,11 @@ void ItemLibraryWidget::updateSearch()
     m_addModuleModel->setSearchText(m_filterText);
 }
 
-void ItemLibraryWidget::handlePriorityImportsChanged()
+void ItemLibraryWidget::setIsDragging(bool val)
 {
-    if (!m_itemLibraryInfo.isNull()) {
-        m_addModuleModel->setPriorityImports(m_itemLibraryInfo->priorityImports());
-        m_addModuleModel->update(m_model->possibleImports());
+    if (m_isDragging != val) {
+        m_isDragging = val;
+        emit isDraggingChanged();
     }
 }
 
@@ -391,6 +376,7 @@ void ItemLibraryWidget::startDragAndDrop(const QVariant &itemLibEntry, const QPo
     // active (and blocks mouse release) if mouse is released at the same spot of the drag start.
     m_itemToDrag = itemLibEntry;
     m_dragStartPoint = mousePos.toPoint();
+    setIsDragging(true);
 }
 
 bool ItemLibraryWidget::subCompEditMode() const
